###########################
Test problems
###########################

The `SMCP repository <https://github.com/cvxopt/smcp/tree/testproblems>`_ contains a number
of SDP problem instances that were created with SMCP and have been
used for :doc:`benchmarks <../benchmarks/index>`. The files
follow the `SDPA sparse data format
<http://euler.nmt.edu/~brian/sdplib/FORMAT>`_ and are compressed with
Bzip2.



